@@ -33,10 +33,14 @@ samQL = function(X, y, p=3, lambda = NULL, nlambda = NULL, lambda.min.ratio = 5e
 	fit$X.ran = X.ran	
 	
 	Z = matrix(0,n,m)
-
+	fit$nkots = matrix(0,p-1,d)
+	fit$Boundary.knots = matrix(0,2,d)
 	for(j in 1:d){
 		tmp = (j-1)*p + c(1:p)
-		Z[,tmp] = ns(X[,j],df=p)
+		tmp0 = ns(X[,j],df=p)
+		Z[,tmp] = tmp0
+		fit$nkots[,j] = attr(tmp0,'knots')
+		fit$Boundary.knots[,j] = attr(tmp0,'Boundary.knots')
 	}
 	
 	Z.mean = apply(Z,2,mean)
@@ -96,7 +100,7 @@ predict.samQL = function(object, newdata,...){
 
 	for(j in 1:d){
 		tmp = (j-1)*object$p + c(1:object$p)
-		Zt[,tmp] = ns(newdata[,j],df=object$p)
+		Zt[,tmp] = ns(newdata[,j],df=object$p,knots=object$knots[,j],Boundary.knots=object$Boundary.knots[,j])
 	}
 	
 	out$values = cbind(Zt,rep(1,nt))%*%rbind(object$w,object$intercept)
